grib2io.tables.section4_discipline2 API documentation

# grib2io.tables.section4_discipline2

View Source

      1table_4_2_2_0  = {
      2'0':['Land Cover (0=sea, 1=land)','Proportion','LAND'],
      3'1':['Surface Roughness','m','SFCR'],
      4'2':['Soil Temperature (Parameter Deprecated, see Note 3)','K','TSOIL'],
      5'3':['Soil Moisture Content (Parameter Deprecated, see Note 1)','unknown','unknown'],
      6'4':['Vegetation','%','VEG'],
      7'5':['Water Runoff','kg m-2','WATR'],
      8'6':['Evapotranspiration','kg-2 s-1','EVAPT'],
      9'7':['Model Terrain Height','m','MTERH'],
     10'8':['Land Use','See Table 4.212','LANDU'],
     11'9':['Volumetric Soil Moisture Content','Proportion','SOILW'],
     12'10':['Ground Heat Flux','W m-2','GFLUX'],
     13'11':['Moisture Availability','%','MSTAV'],
     14'12':['Exchange Coefficient','kg m-2 s-1','SFEXC'],
     15'13':['Plant Canopy Surface Water','kg m-2','CNWAT'],
     16'14':['Blackadars Mixing Length Scale','m','BMIXL'],
     17'15':['Canopy Conductance','m s-1','CCOND'],
     18'16':['Minimal Stomatal Resistance','s m-1','RSMIN'],
     19'17':['Wilting Point (Parameter Deprecated, see Note 1)','Proportion','WILT'],
     20'18':['Solar parameter in canopy conductance','Proportion','RCS'],
     21'19':['Temperature parameter in canopy','Proportion','RCT'],
     22'20':['Humidity parameter in canopy conductance','Proportion','RCQ'],
     23'21':['Soil moisture parameter in canopy conductance','Proportion','RCSOL'],
     24'22':['Soil Moisture (Parameter Deprecated, See Note 3)','unknown','unknown'],
     25'23':['Column-Integrated Soil Water (Parameter Deprecated, See Note 3)','kg m-2','CISOILW'],
     26'24':['Heat Flux','W m-2','HFLUX'],
     27'25':['Volumetric Soil Moisture','m3 m-3','VSOILM'],
     28'26':['Wilting Point','kg m-3','WILT'],
     29'27':['Volumetric Wilting Point','m3 m-3','VWILTP'],
     30'28':['Leaf Area Index','Numeric','LEAINX'],
     31'29':['Evergreen Forest Cover','Proportion','EVGFC'],
     32'30':['Deciduous Forest Cover','Proportion','DECFC'],
     33'31':['Normalized Differential Vegetation Index (NDVI)','Numeric','NDVINX'],
     34'32':['Root Depth of Vegetation','m','RDVEG'],
     35'33':['Water Runoff and Drainage','kg m-2','WROD'],
     36'34':['Surface Water Runoff','kg m-2','SFCWRO'],
     37'35':['Tile Class','See Table 4.243','TCLASS'],
     38'36':['Tile Fraction','Proportion','TFRCT'],
     39'37':['Tile Percentage','%','TPERCT'],
     40'38':['Soil Volumetric Ice Content (Water Equivalent)','m3 m-3','SOILVIC'],
     41'39':['Evapotranspiration Rate','kg m-2 s-1','EVAPTRAT'],
     42'40':['Potential Evapotranspiration Rate','kg m-2 s-1','PEVAPTRAT'],
     43'41':['Snow Melt Rate','kg m-2 s-1','SMRATE'],
     44'42':['Water Runoff and Drainage Rate','kg m-2 s-1','WRDRATE'],
     45'43':['Drainage direction','See Table 4.250','DRAINDIR'],
     46'44':['Upstream Area','m2','UPSAREA'],
     47'45':['Wetland Cover','Proportion','WETCOV'],
     48'46':['Wetland Type','See Table 4.239','WETTYPE'],
     49'47':['Irrigation Cover','Proportion','IRRCOV'],
     50'48':['C4 Crop Cover','Proportion','CROPCOV'],
     51'49':['C4 Grass Cover','Proportion','GRASSCOV'],
     52'50':['Skin Resovoir Content','kg m-2','SKINRC'],
     53'51':['Surface Runoff Rate','kg m-2 s-1','SURFRATE'],
     54'52':['Subsurface Runoff Rate','kg m-2 s-1','SUBSRATE'],
     55'53':['Low-Vegetation Cover','Proportion','LOVEGCOV'],
     56'54':['High-Vegetation Cover','Proportion','HIVEGCOV'],
     57'55':['Leaf Area Index (Low-Vegetation)','m2 m-2','LAILO'],
     58'56':['Leaf Area Index (High-Vegetation)','m2 m-2','LAIHI'],
     59'57':['Type of Low-Vegetation','See Table 4.234','TYPLOVEG'],
     60'58':['Type of High-Vegetation','See Table 4.234','TYPHIVEG'],
     61'59':['Net Ecosystem Exchange Flux','kg-2 s-1','NECOFLUX'],
     62'60':['Gross Primary Production Flux','kg-2 s-1','GROSSFLUX'],
     63'61':['Ecosystem Respiration Flux','kg-2 s-1','ECORFLUX'],
     64'62':['Emissivity','Proportion','EMISS'],
     65'63':['Canopy air temperature','K','CANTMP'],
     66'64-191':['Reserved','unknown','unknown'],
     67'192-254':['Reserved for Local Use','unknown','unknown'],
     68'192':['Volumetric Soil Moisture Content','Fraction','SOILW'],
     69'193':['Ground Heat Flux','W m-2','GFLUX'],
     70'194':['Moisture Availability','%','MSTAV'],
     71'195':['Exchange Coefficient','(kg m-3) (m s-1)','SFEXC'],
     72'196':['Plant Canopy Surface Water','kg m-2','CNWAT'],
     73'197':['Blackadar’s Mixing Length Scale','m','BMIXL'],
     74'198':['Vegetation Type','Integer (0-13)','VGTYP'],
     75'199':['Canopy Conductance','m s-1','CCOND'],
     76'200':['Minimal Stomatal Resistance','s m-1','RSMIN'],
     77'201':['Wilting Point','Fraction','WILT'],
     78'202':['Solar parameter in canopy conductance','Fraction','RCS'],
     79'203':['Temperature parameter in canopy conductance','Fraction','RCT'],
     80'204':['Humidity parameter in canopy conductance','Fraction','RCQ'],
     81'205':['Soil moisture parameter in canopy conductance','Fraction','RCSOL'],
     82'206':['Rate of water dropping from canopy to ground','unknown','RDRIP'],
     83'207':['Ice-free water surface','%','ICWAT'],
     84'208':['Surface exchange coefficients for T and Q divided by delta z','m s-1','AKHS'],
     85'209':['Surface exchange coefficients for U and V divided by delta z','m s-1','AKMS'],
     86'210':['Vegetation canopy temperature','K','VEGT'],
     87'211':['Surface water storage','kg m-2','SSTOR'],
     88'212':['Liquid soil moisture content (non-frozen)','kg m-2','LSOIL'],
     89'213':['Open water evaporation (standing water)','W m-2','EWATR'],
     90'214':['Groundwater recharge','kg m-2','GWREC'],
     91'215':['Flood plain recharge','kg m-2','QREC'],
     92'216':['Roughness length for heat','m','SFCRH'],
     93'217':['Normalized Difference Vegetation Index','unknown','NDVI'],
     94'218':['Land-sea coverage (nearest neighbor) [land=1,sea=0]','unknown','LANDN'],
     95'219':['Asymptotic mixing length scale','m','AMIXL'],
     96'220':['Water vapor added by precip assimilation','kg m-2','WVINC'],
     97'221':['Water condensate added by precip assimilation','kg m-2','WCINC'],
     98'222':['Water Vapor Flux Convergance (Vertical Int)','kg m-2','WVCONV'],
     99'223':['Water Condensate Flux Convergance (Vertical Int)','kg m-2','WCCONV'],
    100'224':['Water Vapor Zonal Flux (Vertical Int)','kg m-2','WVUFLX'],
    101'225':['Water Vapor Meridional Flux (Vertical Int)','kg m-2','WVVFLX'],
    102'226':['Water Condensate Zonal Flux (Vertical Int)','kg m-2','WCUFLX'],
    103'227':['Water Condensate Meridional Flux (Vertical Int)','kg m-2','WCVFLX'],
    104'228':['Aerodynamic conductance','m s-1','ACOND'],
    105'229':['Canopy water evaporation','W m-2','EVCW'],
    106'230':['Transpiration','W m-2','TRANS'],
    107'231':['Seasonally Minimum Green Vegetation Fraction (over 1-year period)','%','VEGMIN'],
    108'232':['Seasonally Maximum Green Vegetation Fraction (over 1-year period)','%','VEGMAX'],
    109'233':['Land Fraction','Fraction','LANDFRC'],
    110'234':['Lake Fraction','Fraction','LAKEFRC'],
    111'235':['Precipitation Advected Heat Flux','W m-2','PAHFLX'],
    112'236':['Water Storage in Aquifer','kg m-2','WATERSA'],
    113'237':['Evaporation of Intercepted Water','kg m-2','EIWATER'],
    114'238':['Plant Transpiration','kg m-2','PLANTTR'],
    115'239':['Soil Surface Evaporation','kg m-2','SOILSE'],
    116'255':['Missing','unknown','unknown'],
    117}
    118table_4_2_2_1  = {
    119'0-191':['Reserved','unknown','unknown'],
    120'192-254':['Reserved for Local Use','unknown','unknown'],
    121'192':['Cold Advisory for Newborn Livestock','unknown','CANL'],
    122'255':['Missing','unknown','unknown'],
    123}
    124table_4_2_2_3  = {
    125'0':['Soil Type','See Table 4.213','SOTYP'],
    126'1':['Upper Layer Soil Temperature','K','UPLST'],
    127'2':['Upper Layer Soil Moisture','kg m-3','UPLSM'],
    128'3':['Lower Layer Soil Moisture','kg m-3','LOWLSM'],
    129'4':['Bottom Layer Soil Temperature','K','BOTLST'],
    130'5':['Liquid Volumetric Soil Moisture(non-frozen)','Proportion','SOILL'],
    131'6':['Number of Soil Layers in Root Zone','Numeric','RLYRS'],
    132'7':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
    133'8':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
    134'9':['Soil Porosity','Proportion','POROS'],
    135'10':['Liquid Volumetric Soil Moisture (Non-Frozen)','m3 m-3','LIQVSM'],
    136'11':['Volumetric Transpiration Stree-Onset(Soil Moisture)','m3 m-3','VOLTSO'],
    137'12':['Transpiration Stree-Onset(Soil Moisture)','kg m-3','TRANSO'],
    138'13':['Volumetric Direct Evaporation Cease(Soil Moisture)','m3 m-3','VOLDEC'],
    139'14':['Direct Evaporation Cease(Soil Moisture)','kg m-3','DIREC'],
    140'15':['Soil Porosity','m3 m-3','SOILP'],
    141'16':['Volumetric Saturation Of Soil Moisture','m3 m-3','VSOSM'],
    142'17':['Saturation Of Soil Moisture','kg m-3','SATOSM'],
    143'18':['Soil Temperature','K','SOILTMP'],
    144'19':['Soil Moisture','kg m-3','SOILMOI'],
    145'20':['Column-Integrated Soil Moisture','kg m-2','CISOILM'],
    146'21':['Soil Ice','kg m-3','SOILICE'],
    147'22':['Column-Integrated Soil Ice','kg m-2','CISICE'],
    148'23':['Liquid Water in Snow Pack','kg m-2','LWSNWP'],
    149'24':['Frost Index','kg day-1','FRSTINX'],
    150'25':['Snow Depth at Elevation Bands','kg m-2','SNWDEB'],
    151'26':['Soil Heat Flux','W m-2','SHFLX'],
    152'27':['Soil Depth','m','SOILDEP'],
    153'28':['Snow Temperature','K','SNOWTMP'],
    154'29':['Ice Temperature','K','ICETEMP'],
    155'30':['Soil wetness index','Numeric','SWET'],
    156'31-191':['Reserved','unknown','unknown'],
    157'192-254':['Reserved for Local Use','unknown','unknown'],
    158'192':['Liquid Volumetric Soil Moisture (non Frozen)','Proportion','SOILL'],
    159'193':['Number of Soil Layers in Root Zone','non-dim','RLYRS'],
    160'194':['Surface Slope Type','Index','SLTYP'],
    161'195':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
    162'196':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
    163'197':['Soil Porosity','Proportion','POROS'],
    164'198':['Direct Evaporation from Bare Soil','W m-2','EVBS'],
    165'199':['Land Surface Precipitation Accumulation','kg m-2','LSPA'],
    166'200':['Bare Soil Surface Skin temperature','K','BARET'],
    167'201':['Average Surface Skin Temperature','K','AVSFT'],
    168'202':['Effective Radiative Skin Temperature','K','RADT'],
    169'203':['Field Capacity','Fraction','FLDCP'],
    170'204':['Soil Moisture Availability In The Top Soil Layer','%','MSTAVTOP'],
    171'255':['Missing','unknown','unknown'],
    172}
    173table_4_2_2_4  = {
    174'0':['Fire Outlook','See Table 4.224','FIREOLK'],
    175'1':['Fire Outlook Due to Dry Thunderstorm','See Table 4.224','FIREODT'],
    176'2':['Haines Index','Numeric','HINDEX'],
    177'3':['Fire Burned Area','%','FBAREA'],
    178'4':['Fosberg Index','Numeric','FOSINDX'],
    179'5':['Fire Weath Index (Canadian Forest Service)','Numeric','FWINX'],
    180'6':['Fine Fuel Moisture Code (Canadian Forest Service)','Numeric','FFMCODE'],
    181'7':['Duff Moisture Code (Canadian Forest Service)','Numeric','DUFMCODE'],
    182'8':['Drought Code (Canadian Forest Service)','Numeric','DRTCODE'],
    183'9':['Initial Fire Spread Index (Canadian Forest Service)','Numeric','INFSINX'],
    184'10':['Fire Build Up Index (Canadian Forest Service)','Numeric','FBUPINX'],
    185'11':['Fire Daily Severity Rating (Canadian Forest Service)','Numeric','FDSRTE'],
    186'12':['Keetch-Byram Drought Index','Numeric','KRIDX'],
    187'13':['Drought Factor (as defined by the Australian forest service)','Numeric','DRFACT'],
    188'14':['Rate of Spread (as defined by the Australian forest service)','m s-1','RATESPRD'],
    189'15':['Fire Danger index (as defined by the Australian forest service)','Numeric','FIREDIDX'],
    190'16':['Spread component (as defined by the US Forest Service National Fire Danger Rating System)','Numeric','SPRDCOMP'],
    191'17':['Burning Index (as defined by the Australian forest service)','Numeric','BURNIDX'],
    192'18':['Ignition Component (as defined by the Australian forest service)','%','IGNCOMP'],
    193'19':['Energy Release Component (as defined by the Australian forest service)','J m-2','ENRELCOM'],
    194'20':['Burning Area','%','BURNAREA'],
    195'21':['Burnable Area','%','BURNABAREA'],
    196'22':['Unburnable Area','%','UNBURNAREA'],
    197'23':['Fuel Load','kg m-2','FUELLOAD'],
    198'24':['Combustion Completeness','%','COMBCO'],
    199'25':['Fuel Moisture Content','kg kg-1','FUELMC'],
    200'26':['Wildfire Potential (as defined by NOAA Global Systems Laboratory)','Numeric','WFIREPOT'],
    201'27':['Live leaf fuel load','kg m-2','LLFL'],
    202'28':['Live wood fuel load','kg m-2','LWFL'],
    203'29':['Dead leaf fuel load','kg m-2','DLFL'],
    204'30':['Dead wood fuel load','kg m-2','DWFL'],
    205'31':['Live fuel moisture content','kg kg-1','LFMC'],
    206'32':['Fine dead leaf moisture content','kg kg-1','FDLMC'],
    207'33':['Dense dead leaf moisture content','kg kg-1','DDLMC'],
    208'34':['Fine dead wood moisture content','kg kg-1','FDWMC'],
    209'35':['Dense dead wood moisture content','kg kg-1','DDWMC'],
    210'36':['Fire radiative power','W','FRADPOW'],
    211'37-191':['Reserved','unknown','unknown'],
    212'192-254':['Reserved for Local Use','unknown','unknown'],
    213'255':['Missing','unknown','unknown'],
    214}
    215table_4_2_2_5  = {
    216'0':['Glacier Cover','Proportion','GLACCOV'],
    217'1':['Glacier Temperature','K','GLACTMP'],
    218'2-191':['Reserved','unknown','unknown'],
    219'192-254':['Reserved for Local Use','unknown','unknown'],
    220'255':['Missing','unknown','unknown'],
    221}

table_4_2_2_0 = {'0': ['Land Cover (0=sea, 1=land)', 'Proportion', 'LAND'], '1': ['Surface Roughness', 'm', 'SFCR'], '2': ['Soil Temperature (Parameter Deprecated, see Note 3)', 'K', 'TSOIL'], '3': ['Soil Moisture Content (Parameter Deprecated, see Note 1)', 'unknown', 'unknown'], '4': ['Vegetation', '%', 'VEG'], '5': ['Water Runoff', 'kg m-2', 'WATR'], '6': ['Evapotranspiration', 'kg-2 s-1', 'EVAPT'], '7': ['Model Terrain Height', 'm', 'MTERH'], '8': ['Land Use', 'See Table 4.212', 'LANDU'], '9': ['Volumetric Soil Moisture Content', 'Proportion', 'SOILW'], '10': ['Ground Heat Flux', 'W m-2', 'GFLUX'], '11': ['Moisture Availability', '%', 'MSTAV'], '12': ['Exchange Coefficient', 'kg m-2 s-1', 'SFEXC'], '13': ['Plant Canopy Surface Water', 'kg m-2', 'CNWAT'], '14': ['Blackadars Mixing Length Scale', 'm', 'BMIXL'], '15': ['Canopy Conductance', 'm s-1', 'CCOND'], '16': ['Minimal Stomatal Resistance', 's m-1', 'RSMIN'], '17': ['Wilting Point (Parameter Deprecated, see Note 1)', 'Proportion', 'WILT'], '18': ['Solar parameter in canopy conductance', 'Proportion', 'RCS'], '19': ['Temperature parameter in canopy', 'Proportion', 'RCT'], '20': ['Humidity parameter in canopy conductance', 'Proportion', 'RCQ'], '21': ['Soil moisture parameter in canopy conductance', 'Proportion', 'RCSOL'], '22': ['Soil Moisture (Parameter Deprecated, See Note 3)', 'unknown', 'unknown'], '23': ['Column-Integrated Soil Water (Parameter Deprecated, See Note 3)', 'kg m-2', 'CISOILW'], '24': ['Heat Flux', 'W m-2', 'HFLUX'], '25': ['Volumetric Soil Moisture', 'm3 m-3', 'VSOILM'], '26': ['Wilting Point', 'kg m-3', 'WILT'], '27': ['Volumetric Wilting Point', 'm3 m-3', 'VWILTP'], '28': ['Leaf Area Index', 'Numeric', 'LEAINX'], '29': ['Evergreen Forest Cover', 'Proportion', 'EVGFC'], '30': ['Deciduous Forest Cover', 'Proportion', 'DECFC'], '31': ['Normalized Differential Vegetation Index (NDVI)', 'Numeric', 'NDVINX'], '32': ['Root Depth of Vegetation', 'm', 'RDVEG'], '33': ['Water Runoff and Drainage', 'kg m-2', 'WROD'], '34': ['Surface Water Runoff', 'kg m-2', 'SFCWRO'], '35': ['Tile Class', 'See Table 4.243', 'TCLASS'], '36': ['Tile Fraction', 'Proportion', 'TFRCT'], '37': ['Tile Percentage', '%', 'TPERCT'], '38': ['Soil Volumetric Ice Content (Water Equivalent)', 'm3 m-3', 'SOILVIC'], '39': ['Evapotranspiration Rate', 'kg m-2 s-1', 'EVAPTRAT'], '40': ['Potential Evapotranspiration Rate', 'kg m-2 s-1', 'PEVAPTRAT'], '41': ['Snow Melt Rate', 'kg m-2 s-1', 'SMRATE'], '42': ['Water Runoff and Drainage Rate', 'kg m-2 s-1', 'WRDRATE'], '43': ['Drainage direction', 'See Table 4.250', 'DRAINDIR'], '44': ['Upstream Area', 'm2', 'UPSAREA'], '45': ['Wetland Cover', 'Proportion', 'WETCOV'], '46': ['Wetland Type', 'See Table 4.239', 'WETTYPE'], '47': ['Irrigation Cover', 'Proportion', 'IRRCOV'], '48': ['C4 Crop Cover', 'Proportion', 'CROPCOV'], '49': ['C4 Grass Cover', 'Proportion', 'GRASSCOV'], '50': ['Skin Resovoir Content', 'kg m-2', 'SKINRC'], '51': ['Surface Runoff Rate', 'kg m-2 s-1', 'SURFRATE'], '52': ['Subsurface Runoff Rate', 'kg m-2 s-1', 'SUBSRATE'], '53': ['Low-Vegetation Cover', 'Proportion', 'LOVEGCOV'], '54': ['High-Vegetation Cover', 'Proportion', 'HIVEGCOV'], '55': ['Leaf Area Index (Low-Vegetation)', 'm2 m-2', 'LAILO'], '56': ['Leaf Area Index (High-Vegetation)', 'm2 m-2', 'LAIHI'], '57': ['Type of Low-Vegetation', 'See Table 4.234', 'TYPLOVEG'], '58': ['Type of High-Vegetation', 'See Table 4.234', 'TYPHIVEG'], '59': ['Net Ecosystem Exchange Flux', 'kg-2 s-1', 'NECOFLUX'], '60': ['Gross Primary Production Flux', 'kg-2 s-1', 'GROSSFLUX'], '61': ['Ecosystem Respiration Flux', 'kg-2 s-1', 'ECORFLUX'], '62': ['Emissivity', 'Proportion', 'EMISS'], '63': ['Canopy air temperature', 'K', 'CANTMP'], '64-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Volumetric Soil Moisture Content', 'Fraction', 'SOILW'], '193': ['Ground Heat Flux', 'W m-2', 'GFLUX'], '194': ['Moisture Availability', '%', 'MSTAV'], '195': ['Exchange Coefficient', '(kg m-3) (m s-1)', 'SFEXC'], '196': ['Plant Canopy Surface Water', 'kg m-2', 'CNWAT'], '197': ['Blackadar’s Mixing Length Scale', 'm', 'BMIXL'], '198': ['Vegetation Type', 'Integer (0-13)', 'VGTYP'], '199': ['Canopy Conductance', 'm s-1', 'CCOND'], '200': ['Minimal Stomatal Resistance', 's m-1', 'RSMIN'], '201': ['Wilting Point', 'Fraction', 'WILT'], '202': ['Solar parameter in canopy conductance', 'Fraction', 'RCS'], '203': ['Temperature parameter in canopy conductance', 'Fraction', 'RCT'], '204': ['Humidity parameter in canopy conductance', 'Fraction', 'RCQ'], '205': ['Soil moisture parameter in canopy conductance', 'Fraction', 'RCSOL'], '206': ['Rate of water dropping from canopy to ground', 'unknown', 'RDRIP'], '207': ['Ice-free water surface', '%', 'ICWAT'], '208': ['Surface exchange coefficients for T and Q divided by delta z', 'm s-1', 'AKHS'], '209': ['Surface exchange coefficients for U and V divided by delta z', 'm s-1', 'AKMS'], '210': ['Vegetation canopy temperature', 'K', 'VEGT'], '211': ['Surface water storage', 'kg m-2', 'SSTOR'], '212': ['Liquid soil moisture content (non-frozen)', 'kg m-2', 'LSOIL'], '213': ['Open water evaporation (standing water)', 'W m-2', 'EWATR'], '214': ['Groundwater recharge', 'kg m-2', 'GWREC'], '215': ['Flood plain recharge', 'kg m-2', 'QREC'], '216': ['Roughness length for heat', 'm', 'SFCRH'], '217': ['Normalized Difference Vegetation Index', 'unknown', 'NDVI'], '218': ['Land-sea coverage (nearest neighbor) [land=1,sea=0]', 'unknown', 'LANDN'], '219': ['Asymptotic mixing length scale', 'm', 'AMIXL'], '220': ['Water vapor added by precip assimilation', 'kg m-2', 'WVINC'], '221': ['Water condensate added by precip assimilation', 'kg m-2', 'WCINC'], '222': ['Water Vapor Flux Convergance (Vertical Int)', 'kg m-2', 'WVCONV'], '223': ['Water Condensate Flux Convergance (Vertical Int)', 'kg m-2', 'WCCONV'], '224': ['Water Vapor Zonal Flux (Vertical Int)', 'kg m-2', 'WVUFLX'], '225': ['Water Vapor Meridional Flux (Vertical Int)', 'kg m-2', 'WVVFLX'], '226': ['Water Condensate Zonal Flux (Vertical Int)', 'kg m-2', 'WCUFLX'], '227': ['Water Condensate Meridional Flux (Vertical Int)', 'kg m-2', 'WCVFLX'], '228': ['Aerodynamic conductance', 'm s-1', 'ACOND'], '229': ['Canopy water evaporation', 'W m-2', 'EVCW'], '230': ['Transpiration', 'W m-2', 'TRANS'], '231': ['Seasonally Minimum Green Vegetation Fraction (over 1-year period)', '%', 'VEGMIN'], '232': ['Seasonally Maximum Green Vegetation Fraction (over 1-year period)', '%', 'VEGMAX'], '233': ['Land Fraction', 'Fraction', 'LANDFRC'], '234': ['Lake Fraction', 'Fraction', 'LAKEFRC'], '235': ['Precipitation Advected Heat Flux', 'W m-2', 'PAHFLX'], '236': ['Water Storage in Aquifer', 'kg m-2', 'WATERSA'], '237': ['Evaporation of Intercepted Water', 'kg m-2', 'EIWATER'], '238': ['Plant Transpiration', 'kg m-2', 'PLANTTR'], '239': ['Soil Surface Evaporation', 'kg m-2', 'SOILSE'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_2_1 = {'0-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Cold Advisory for Newborn Livestock', 'unknown', 'CANL'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_2_3 = {'0': ['Soil Type', 'See Table 4.213', 'SOTYP'], '1': ['Upper Layer Soil Temperature', 'K', 'UPLST'], '2': ['Upper Layer Soil Moisture', 'kg m-3', 'UPLSM'], '3': ['Lower Layer Soil Moisture', 'kg m-3', 'LOWLSM'], '4': ['Bottom Layer Soil Temperature', 'K', 'BOTLST'], '5': ['Liquid Volumetric Soil Moisture(non-frozen)', 'Proportion', 'SOILL'], '6': ['Number of Soil Layers in Root Zone', 'Numeric', 'RLYRS'], '7': ['Transpiration Stress-onset (soil moisture)', 'Proportion', 'SMREF'], '8': ['Direct Evaporation Cease (soil moisture)', 'Proportion', 'SMDRY'], '9': ['Soil Porosity', 'Proportion', 'POROS'], '10': ['Liquid Volumetric Soil Moisture (Non-Frozen)', 'm3 m-3', 'LIQVSM'], '11': ['Volumetric Transpiration Stree-Onset(Soil Moisture)', 'm3 m-3', 'VOLTSO'], '12': ['Transpiration Stree-Onset(Soil Moisture)', 'kg m-3', 'TRANSO'], '13': ['Volumetric Direct Evaporation Cease(Soil Moisture)', 'm3 m-3', 'VOLDEC'], '14': ['Direct Evaporation Cease(Soil Moisture)', 'kg m-3', 'DIREC'], '15': ['Soil Porosity', 'm3 m-3', 'SOILP'], '16': ['Volumetric Saturation Of Soil Moisture', 'm3 m-3', 'VSOSM'], '17': ['Saturation Of Soil Moisture', 'kg m-3', 'SATOSM'], '18': ['Soil Temperature', 'K', 'SOILTMP'], '19': ['Soil Moisture', 'kg m-3', 'SOILMOI'], '20': ['Column-Integrated Soil Moisture', 'kg m-2', 'CISOILM'], '21': ['Soil Ice', 'kg m-3', 'SOILICE'], '22': ['Column-Integrated Soil Ice', 'kg m-2', 'CISICE'], '23': ['Liquid Water in Snow Pack', 'kg m-2', 'LWSNWP'], '24': ['Frost Index', 'kg day-1', 'FRSTINX'], '25': ['Snow Depth at Elevation Bands', 'kg m-2', 'SNWDEB'], '26': ['Soil Heat Flux', 'W m-2', 'SHFLX'], '27': ['Soil Depth', 'm', 'SOILDEP'], '28': ['Snow Temperature', 'K', 'SNOWTMP'], '29': ['Ice Temperature', 'K', 'ICETEMP'], '30': ['Soil wetness index', 'Numeric', 'SWET'], '31-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Liquid Volumetric Soil Moisture (non Frozen)', 'Proportion', 'SOILL'], '193': ['Number of Soil Layers in Root Zone', 'non-dim', 'RLYRS'], '194': ['Surface Slope Type', 'Index', 'SLTYP'], '195': ['Transpiration Stress-onset (soil moisture)', 'Proportion', 'SMREF'], '196': ['Direct Evaporation Cease (soil moisture)', 'Proportion', 'SMDRY'], '197': ['Soil Porosity', 'Proportion', 'POROS'], '198': ['Direct Evaporation from Bare Soil', 'W m-2', 'EVBS'], '199': ['Land Surface Precipitation Accumulation', 'kg m-2', 'LSPA'], '200': ['Bare Soil Surface Skin temperature', 'K', 'BARET'], '201': ['Average Surface Skin Temperature', 'K', 'AVSFT'], '202': ['Effective Radiative Skin Temperature', 'K', 'RADT'], '203': ['Field Capacity', 'Fraction', 'FLDCP'], '204': ['Soil Moisture Availability In The Top Soil Layer', '%', 'MSTAVTOP'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_2_4 = {'0': ['Fire Outlook', 'See Table 4.224', 'FIREOLK'], '1': ['Fire Outlook Due to Dry Thunderstorm', 'See Table 4.224', 'FIREODT'], '2': ['Haines Index', 'Numeric', 'HINDEX'], '3': ['Fire Burned Area', '%', 'FBAREA'], '4': ['Fosberg Index', 'Numeric', 'FOSINDX'], '5': ['Fire Weath Index (Canadian Forest Service)', 'Numeric', 'FWINX'], '6': ['Fine Fuel Moisture Code (Canadian Forest Service)', 'Numeric', 'FFMCODE'], '7': ['Duff Moisture Code (Canadian Forest Service)', 'Numeric', 'DUFMCODE'], '8': ['Drought Code (Canadian Forest Service)', 'Numeric', 'DRTCODE'], '9': ['Initial Fire Spread Index (Canadian Forest Service)', 'Numeric', 'INFSINX'], '10': ['Fire Build Up Index (Canadian Forest Service)', 'Numeric', 'FBUPINX'], '11': ['Fire Daily Severity Rating (Canadian Forest Service)', 'Numeric', 'FDSRTE'], '12': ['Keetch-Byram Drought Index', 'Numeric', 'KRIDX'], '13': ['Drought Factor (as defined by the Australian forest service)', 'Numeric', 'DRFACT'], '14': ['Rate of Spread (as defined by the Australian forest service)', 'm s-1', 'RATESPRD'], '15': ['Fire Danger index (as defined by the Australian forest service)', 'Numeric', 'FIREDIDX'], '16': ['Spread component (as defined by the US Forest Service National Fire Danger Rating System)', 'Numeric', 'SPRDCOMP'], '17': ['Burning Index (as defined by the Australian forest service)', 'Numeric', 'BURNIDX'], '18': ['Ignition Component (as defined by the Australian forest service)', '%', 'IGNCOMP'], '19': ['Energy Release Component (as defined by the Australian forest service)', 'J m-2', 'ENRELCOM'], '20': ['Burning Area', '%', 'BURNAREA'], '21': ['Burnable Area', '%', 'BURNABAREA'], '22': ['Unburnable Area', '%', 'UNBURNAREA'], '23': ['Fuel Load', 'kg m-2', 'FUELLOAD'], '24': ['Combustion Completeness', '%', 'COMBCO'], '25': ['Fuel Moisture Content', 'kg kg-1', 'FUELMC'], '26': ['Wildfire Potential (as defined by NOAA Global Systems Laboratory)', 'Numeric', 'WFIREPOT'], '27': ['Live leaf fuel load', 'kg m-2', 'LLFL'], '28': ['Live wood fuel load', 'kg m-2', 'LWFL'], '29': ['Dead leaf fuel load', 'kg m-2', 'DLFL'], '30': ['Dead wood fuel load', 'kg m-2', 'DWFL'], '31': ['Live fuel moisture content', 'kg kg-1', 'LFMC'], '32': ['Fine dead leaf moisture content', 'kg kg-1', 'FDLMC'], '33': ['Dense dead leaf moisture content', 'kg kg-1', 'DDLMC'], '34': ['Fine dead wood moisture content', 'kg kg-1', 'FDWMC'], '35': ['Dense dead wood moisture content', 'kg kg-1', 'DDWMC'], '36': ['Fire radiative power', 'W', 'FRADPOW'], '37-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_2_5 = {'0': ['Glacier Cover', 'Proportion', 'GLACCOV'], '1': ['Glacier Temperature', 'K', 'GLACTMP'], '2-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}